@@ -56,7 +56,6 @@ void find_wrappers(xmlNode* node, NodeMap& node_map)
     case XML_ATTRIBUTE_DECL:
     case XML_ENTITY_DECL:
     case XML_DOCUMENT_NODE:
-    case XML_HTML_DOCUMENT_NODE:
       has_attributes = false;
       break;
     default:
@@ -103,7 +102,6 @@ void remove_found_wrappers(xmlNode* node, NodeMap& node_map)
     case XML_ATTRIBUTE_DECL:
     case XML_ENTITY_DECL:
     case XML_DOCUMENT_NODE:
-    case XML_HTML_DOCUMENT_NODE:
       has_attributes = false;
       break;
     default:
@@ -429,11 +427,6 @@ void Document::set_entity_declaration(const Glib::ustring& name, XmlEntityType t
     throw internal_error("Could not add entity declaration " + name);
 }
 
-int Document::process_xinclude(bool generate_xinclude_nodes)
-{
-  return process_xinclude(generate_xinclude_nodes, true);
-}
-
 int Document::process_xinclude(bool generate_xinclude_nodes, bool fixup_base_uris)
 {
   NodeMap node_map;
@@ -464,7 +457,6 @@ int Document::process_xinclude(bool generate_xinclude_nodes, bool fixup_base_uri
       delete reinterpret_cast<Dtd*>(node);
       break;
     case XML_DOCUMENT_NODE:
-    case XML_HTML_DOCUMENT_NODE:
       delete reinterpret_cast<Document*>(node);
       break;
     default:
